#ifndef DEFS_SHOUTCAST_H
#define DEFS_SHOUTCAST_H

#define SHOUTCAST_PREF_KEY "[Shoutcast]"
#define SHOUTCAST_DEFAULT_PORT "8000"

#define SHOUTCAST_CHANNELS_STEREO 2

#define SHOUTCAST_SERVER_SHOUTCAST "Shoutcast"
#define SHOUTCAST_SERVER_ICECAST1 "Icecast1"
#define SHOUTCAST_SERVER_ICECAST2 "Icecast2"

#define SHOUTCAST_BITRATE_320KBPS 320
#define SHOUTCAST_BITRATE_256KBPS 256
#define SHOUTCAST_BITRATE_224KBPS 224
#define SHOUTCAST_BITRATE_192KBPS 192
#define SHOUTCAST_BITRATE_160KBPS 160
#define SHOUTCAST_BITRATE_128KBPS 128
#define SHOUTCAST_BITRATE_112KBPS 112
#define SHOUTCAST_BITRATE_96KBPS 96
#define SHOUTCAST_BITRATE_80KBPS 80
#define SHOUTCAST_BITRATE_64KBPS 64
#define SHOUTCAST_BITRATE_48KBPS 48
#define SHOUTCAST_BITRATE_32KBPS 32

#define SHOUTCAST_FORMAT_MP3 "MP3"
#define SHOUTCAST_FORMAT_OV "OggVorbis"

#endif /* DEFS_SHOUTCAST_H */
